# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-08-09 19:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('assignment_desk', '0003_auto_20180615_1551'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='role',
            options={'ordering': ['priority', 'name']},
        ),
        migrations.AlterModelOptions(
            name='roletype',
            options={'ordering': ['priority', 'name']},
        ),
        migrations.AlterField(
            model_name='assignment',
            name='staffer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='assignments', to='editorial_staff.Staffer'),
        ),
    ]
