# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-08-14 19:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('assignment_desk', '0004_auto_20180809_1432'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='assignment',
            options={'ordering': ['role', 'day']},
        ),
    ]
